@@ -118,9 +118,8 @@ enum {
 static GList *history_list;
 static int side_pane_width_auto_value = SIDE_PANE_MINIMUM_WIDTH;
 
-static void update_sidebar_panels_from_preferences (NautilusWindow *window);
-static void sidebar_panels_changed_callback        (gpointer        user_data);
-static void cancel_view_as_callback                (NautilusWindow *window);
+static void add_sidebar_panels                  (NautilusWindow *window);
+static void cancel_view_as_callback             (NautilusWindow *window);
 
 GNOME_CLASS_BOILERPLATE (NautilusWindow, nautilus_window,
 			 BonoboWindow, BONOBO_TYPE_WINDOW)
@@ -156,20 +155,11 @@ set_up_default_icon_list (void)
 }
 
 static void
-add_sidebar_panel_callback (const char *name,
-			    const char *iid,
-			    const char *preference_key,
-			    gpointer callback_data) 
+icons_changed_callback (GObject *factory, NautilusWindow *window)
 {
-	g_assert (name != NULL);
-	g_assert (iid != NULL);
-	g_assert (preference_key != NULL);
-	g_assert (NAUTILUS_IS_WINDOW (callback_data));
-	
-	eel_preferences_add_callback_while_alive (preference_key,
-						  sidebar_panels_changed_callback,
-						  callback_data,
-						  G_OBJECT (callback_data));
+	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
+
+	nautilus_window_update_icon (window);
 }
 
 static void
@@ -197,6 +187,13 @@ nautilus_window_instance_init (NautilusWindow *window)
 		 nautilus_window_get_ui_container (window),
 		 NULL);
 
+	/* Register IconFactory callback to update the window border icon
+	 * when the icon-theme is changed.
+	 */
+	g_signal_connect_object (nautilus_icon_factory_get (), "icons_changed",
+				 G_CALLBACK (icons_changed_callback), window,
+				 0);
+
 	/* Create a separate component so when we remove the status
 	 * we don't loose the status bar
 	 */
@@ -208,9 +205,6 @@ nautilus_window_instance_init (NautilusWindow *window)
 
 	gtk_quit_add_destroy (1, GTK_OBJECT (window));
 
-	/* Keep track of changes in enabled state of sidebar panels */
-	nautilus_sidebar_for_each_panel (add_sidebar_panel_callback, window);
-
 	/* Keep the main event loop alive as long as the window exists */
 	nautilus_main_event_loop_register (GTK_OBJECT (window));
 }
@@ -676,7 +670,7 @@ nautilus_window_set_up_sidebar (NautilusWindow *window)
 				      _("Information"));
 
 	/* Set up the sidebar panels. */
-	update_sidebar_panels_from_preferences (window);
+	add_sidebar_panels (window);
 	
 	gtk_widget_show (GTK_WIDGET (window->sidebar));
 }
@@ -898,11 +892,6 @@ nautilus_window_unrealize (GtkWidget *widget)
 		window->details->throbber_property_bag = CORBA_OBJECT_NIL;
 	}
 
-	if (window->details->throbber_listener != CORBA_OBJECT_NIL) {
-		CORBA_Object_release (window->details->throbber_listener, NULL);
-		window->details->throbber_listener = CORBA_OBJECT_NIL;
-	}
-
 	GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
 }
 
@@ -1150,7 +1139,7 @@ create_view_as_menu_item (NautilusWindow *window,
         char *menu_label;
 
 	menu_label = g_strdup (_(identifier->view_as_label));
-	menu_item = gtk_menu_item_new_with_label (menu_label);
+	menu_item = gtk_menu_item_new_with_mnemonic (menu_label);
 	g_free (menu_label);
 
 	g_signal_connect_object (menu_item, "activate",
@@ -1935,18 +1924,14 @@ nautilus_window_set_content_view_widget (NautilusWindow *window,
 }
 
 /**
- * update_sidebar_panels_from_preferences:
+ * add_sidebar_panels:
  * @window:	A NautilusWindow
  *
- * Update the current list of sidebar panels from preferences.   
- *
- * Disabled panels are removed if they are already in the list.
- *
- * Enabled panels are added if they are not already in the list.
+ * Adds all sidebars available
  *
  */
 static void
-update_sidebar_panels_from_preferences (NautilusWindow *window)
+add_sidebar_panels (NautilusWindow *window)
 {
 	GList *identifier_list;
 
@@ -1956,25 +1941,11 @@ update_sidebar_panels_from_preferences (NautilusWindow *window)
 		return;
 	}
 
-	/* Obtain list of enabled view identifiers */
-	identifier_list = nautilus_sidebar_get_enabled_sidebar_panel_view_identifiers ();
+	identifier_list = nautilus_sidebar_get_all_sidebar_panel_view_identifiers ();
 	nautilus_window_set_sidebar_panels (window, identifier_list);
 	nautilus_view_identifier_list_free (identifier_list);
 }
 
-/**
- * sidebar_panels_changed_callback:
- * @user_data:	Callback data
- *
- * Called when enabled/disabled preferences change for any
- * sidebar panel.
- */
-static void
-sidebar_panels_changed_callback (gpointer user_data)
-{
-	update_sidebar_panels_from_preferences (NAUTILUS_WINDOW (user_data));
-}
-
 static void 
 show_dock_item (NautilusWindow *window, const char *dock_item_path)
 {
@@ -2017,12 +1988,14 @@ nautilus_window_hide_location_bar (NautilusWindow *window)
 {
 	window->details->temporary_navigation_bar = FALSE;
 	hide_dock_item (window, LOCATION_BAR_PATH);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR, FALSE);
 }
 
 void 
 nautilus_window_show_location_bar (NautilusWindow *window)
 {
 	show_dock_item (window, LOCATION_BAR_PATH);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_LOCATION_BAR, TRUE);
 }
 
 gboolean
@@ -2035,6 +2008,7 @@ void
 nautilus_window_hide_toolbar (NautilusWindow *window)
 {
 	hide_dock_item (window, TOOLBAR_PATH);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR, FALSE);
 }
 
 void 
@@ -2042,6 +2016,7 @@ nautilus_window_show_toolbar (NautilusWindow *window)
 {
 	nautilus_window_activate_throbber (window);
 	show_dock_item (window, TOOLBAR_PATH);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_TOOLBAR, TRUE);
 }
 
 gboolean
@@ -2059,6 +2034,7 @@ nautilus_window_hide_sidebar (NautilusWindow *window)
 
 	nautilus_window_tear_down_sidebar (window);
 	nautilus_window_update_show_hide_menu_items (window);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR, FALSE);
 }
 
 void 
@@ -2070,6 +2046,7 @@ nautilus_window_show_sidebar (NautilusWindow *window)
 
 	nautilus_window_set_up_sidebar (window);
 	nautilus_window_update_show_hide_menu_items (window);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_SIDEBAR, TRUE);
 }
 
 gboolean
@@ -2087,6 +2064,7 @@ nautilus_window_hide_status_bar (NautilusWindow *window)
 	hide_dock_item (window, STATUS_BAR_PATH);
 
 	nautilus_window_update_show_hide_menu_items (window);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR, FALSE);
 }
 
 void 
@@ -2095,6 +2073,7 @@ nautilus_window_show_status_bar (NautilusWindow *window)
 	show_dock_item (window, STATUS_BAR_PATH);
 
 	nautilus_window_update_show_hide_menu_items (window);
+	eel_preferences_set_boolean (NAUTILUS_PREFERENCES_START_WITH_STATUS_BAR, TRUE);
 }
 
 gboolean
